@@ -18,7 +18,7 @@ foreach oldie [glob -nocomplain $tclLibDir/tclcurl*] {
     catch {file delete -force $oldie}
 }
 
-file copy -force tclcurl0.132 $tclLibDir
+file copy -force tclcurl0.14.1 $tclLibDir
 
 foreach sslFile [glob -nocomplain ssl/*] {
     catch {file copy -force $sslFile $windowsSystem}
